pub struct JsonSchemaWrapper(pub Value);Expand description
A thin wrapper around serde_json::Value representing a JSON Schema.
This newtype exists to allow future validation hooks and schema
manipulation to be added without changing the public API of EndpointMeta.
Tuple Fields
0: ValueTrait Implementations
Sourceimpl Clone for JsonSchemaWrapper
impl Clone for JsonSchemaWrapper
Sourcefn clone(&self) -> JsonSchemaWrapper
fn clone(&self) -> JsonSchemaWrapper
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JsonSchemaWrapper
impl Debug for JsonSchemaWrapper
Sourceimpl<'de> Deserialize<'de> for JsonSchemaWrapper
impl<'de> Deserialize<'de> for JsonSchemaWrapper
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<JsonSchemaWrapper> for Value
impl From<JsonSchemaWrapper> for Value
Sourcefn from(wrapper: JsonSchemaWrapper) -> Value
fn from(wrapper: JsonSchemaWrapper) -> Value
Unwrap a JsonSchemaWrapper back into its inner serde_json::Value.
Sourceimpl From<Value> for JsonSchemaWrapper
impl From<Value> for JsonSchemaWrapper
Sourcefn from(value: Value) -> Self
fn from(value: Value) -> Self
Wrap a raw serde_json::Value into a JsonSchemaWrapper.